#!/usr/bin/env python
# coding: utf-8

from typing import List, Any
import os
import json
import csv
import pickle
from dsframework.base.common import functions

class ZIDS_SharedArtifacts():

    def __init__(self) -> None:
        self.base_dir = os.getcwd()
        self.parent_dir = os.path.dirname(os.getcwd())
        self.load_config_json()
        self.load_vocabs()
        self.load_artifacts()

    def load_config_json(self):
        if os.path.exists('config.json'):
            data = functions.load_json('config.json')
            for item in data:
                setattr(self, item, data[item])

    def load_vocabs(self):
        if hasattr(self, 'vocabs'):
            for item in self.vocabs:
                self.load_file(item)

    def load_artifacts(self):
        if hasattr(self, 'artifacts'):
            for item in self.artifacts:
                self.load_file(item)

    def load_file(self, item):
        file_type = item['type']
        path = item['path']
        name = item['name']
        if path:
            absolute_path = self.base_dir + '/' + path
            if file_type == 'json':
                self.load_json(absolute_path, name)
            elif file_type == 'csv':
                self.load_csv(absolute_path, name)
            elif file_type == 'pickle':
                self.load_csv(absolute_path, name)
            elif file_type == 'tensorflow':
                self.load_tensorflow(absolute_path, name)

    def load_json(self, path, name):
        with open(path) as json_file:
            setattr(self, name, json.load(json_file))

    def load_csv(self, path, name):
        with open(path) as csv_file:
            setattr(self, name, functions.flatten_list(list(csv.reader(csv_file))))

    def load_pickle(self, path, name):
        with open(path, 'rb') as pickle_file:
            setattr(self, name, pickle.load(pickle_file))

    def load_tensorflow(self, path, name):
        raise NotImplementedError
        # with open(path) as tensorflow_file:
        #     setattr(self, name, tf.keras.models.load_model(tensorflow_file))

    def get(self, key, default=None):
        if key in self.__dict__:
            return self.__dict__[key]
        return default



#!/usr/bin/env python
# coding: utf-8

from typing import Any
from dsframework.base.common import ZIDS_Object

class ZIDS_Predictable(ZIDS_Object):

    def __init__(self) -> None:
        super().__init__()
        self.name:str = ''
        self.input:Any = None
        self.target:Any = None    
        self.pred: Any = None
        self.prob:float = -1.0
        self.forced_pred:Any = None
        self.forced_reason:str = 'Did Not Forced'



 # !/usr/bin/env python
# coding: utf-8

from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
from typing import List, Union

from dsframework.base.pipeline.postprocessor import ZIDS_Postprocessor
from pipeline.artifacts.shared_artifacts import generatedProjectNameSharedArtifacts
from pipeline.schema.outputs import generatedProjectNameOutputs

class generatedClass(ZIDS_Postprocessor):

    def __init__(self, artifacts: generatedProjectNameSharedArtifacts = None) -> None:
        super().__init__(artifacts)

    def config(self):
        pass

    def normalize_output(self, predictables: Union[ZIDS_Predictable, List[ZIDS_Predictable]]) -> Union[generatedProjectNameOutputs, List[generatedProjectNameOutputs]]:
        output: generatedProjectNameOutputs = ''
        isList = isinstance(predictables, list)
        if isList:
            output: List[generatedProjectNameOutputs] = []
        if isList:
            if predictables and len(predictables):
                for item in predictables:
                    output.append(self.get_output_object(item))
        else:
            output = self.get_output_object(predictables)
        return output

    def get_output_object(self, predictable):
        raise NotImplementedError
        pred = predictable[0]
        prob = predictable[-1]

        if(pred >= self.artifacts.threshold):
            prob = True
        else:
            prob = False

        return generatedProjectNameOutputs(pred=pred, prob=prob)



import json
import pickle
from datetime import datetime

from dsframework.base.common.regex_handler import RegexHandler

regex = RegexHandler

def flatten(d,sep="_"):
    import collections

    obj = collections.OrderedDict()

    def recurse(t, parent_key=""):

        if isinstance(t, dict):
            for k, v in t.items():
                recurse(v, parent_key + sep + k if parent_key else k)
        else:
            obj[parent_key] = t
    recurse(d)
    return obj

def get_from_dict(key, container:dict, default='', delete=False):
    if not container or type(container) is not dict:
        return default
    if key in container:
        val = container[key]
        if delete:
            del container[key]
        return val
    return default

def get_date_time(short=False):
    now = datetime.now()
    form = '%d/%m/%Y %H:%M:%S' if not short else '%d_%m_%Y'
    dt_string = now.strftime(form)
    return dt_string

def load_pickle(path):
    pkl = None
    with open(path, 'rb') as fid:
        pkl =  pickle.load(fid)
    return pkl

def load_json(path):
    jsn = None
    with open(path) as fid:
        jsn =  json.load(fid)
    return jsn 

def save_pickle(obj, path):
    with open(path, 'wb') as fid:
        pickle.dump(obj, fid)

def save_json(obj, path):
    with open(path, 'w') as f:
        json.dump(f, obj)

def remove_empty_leafs(d):
    if not isinstance(d, (dict, list)):
        return d
    if isinstance(d, list):
        return [v for v in (remove_empty_leafs(v) for v in d) if v]
    return {k: v for k, v in ((k, remove_empty_leafs(v)) for k, v in d.items()) if v}

def flatten_list(l):
    def get_el(el):
        if type(el) is not list:
            return [el]
        return el
    l2 = [get_el(el) for el in l]
    flatten = lambda l: [item for sublist in l for item in sublist]
    return flatten(l2)

def is_list_of_list(l):
    for el in l:
        if type(el) is list:
            return True
    return False

def ngram_splitter(line, ngram=3,all_grams=False):
    tokens       = line.split(" ")
    loop_index   = 1
    result       = []
    ngram_window = []
    for token in tokens:
        ngram_window.append(token)
        if all_grams==False:
            if loop_index >= ngram:
                result.append(" ".join(ngram_window))
        else:
            for j in range(1,ngram+1):
                if loop_index >=j:
                    if len(result)<j:
                        result.append([" ".join(ngram_window[0:loop_index-1+j])])
                    else:
                        result[j-1].append(" ".join(ngram_window[min(loop_index-j,ngram-j):min(ngram,loop_index+j-1)]))
        if loop_index >= ngram:
            ngram_window = ngram_window[1:]
        loop_index +=1 
    return result
    
def remove_duplicates_lines(lines = []):
    ls = lines 
    lookup = set()  # a temporary lookup set
    ls = [x for x in ls if x not in lookup and lookup.add(x) is None]
    return ls 
    
def get_html_block_elements_list():
    return ['<address', '<article', '<aside', '<blockquote', '<canvas', '<dd', '<div',
            '<dl',
            '<dt', '<fieldset', '<figcaption', '<figure', '<footer', '<form', '<h1',
            '<h2', '<h3',
            '<h4', '<h5', '<h6', '<header', '<hr', '<li', '<main', '<nav',
            '<noscript', '<ol', '<p', '<pre', '<section', '<table', '<tfoot', '<ul',
            '<video']

def get_html_inline_elements_list():
    return ['<a', '<abbr', '<acronym', '<b', '<bdo', '<big', '<br', '<button', '<cite',
            '<code', '<dfn', '<em',
            '<i', '<img', '<input', '<kbd', '<label', '<map', '<object', '<output',
            '<q', '<samp', '<script',
            '<select', '<small', '<span', '<strong', '<sub', '<sup', '<textarea',
            '<time', '<tt', '<var']



# !/usr/bin/env python
# coding: utf-8

from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable


class generatedClass(ZIDS_Predictable):

    def __init__(self) -> None:
        super().__init__()




from typing import List, Any
from dsframework.base.common.component import ZIDS_Component

class generatedClass(ZIDS_Component):

    def __init__(self, artifacts=None) -> None:
        super().__init__(artifacts)

    def execute(self, predictables: List[Any], **kwargs) -> List[Any]:
        return predictables



#!/usr/bin/env python
# coding: utf-8

from typing import List, Any
from dsframework.base.common.component import ZIDS_Component
from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
from dsframework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts

class ZIDS_Postprocessor(ZIDS_Component):

    def __init__(self, artifacts:ZIDS_SharedArtifacts=None) -> None:
        super().__init__(artifacts)

    def normalize_output(self, predictables:List[ZIDS_Predictable]) -> Any:
        raise NotImplementedError
        # Should return the final output

    def execute(self,  predictables:List[Any]) -> Any:
        return self.normalize_output(super().execute(predictables))



# !/usr/bin/env python
# coding: utf-8

from typing import List, Any

from dsframework.base.pipeline.preprocessor import ZIDS_Preprocessor
from pipeline.schema.inputs import generatedProjectNameInputs
from pipeline.schema.outputs import generatedProjectNameOutputs
from pipeline.artifacts.shared_artifacts import generatedProjectNameSharedArtifacts


class generatedClass(ZIDS_Preprocessor):

    def __init__(self, artifacts: generatedProjectNameSharedArtifacts = None):
        super().__init__(artifacts)

    def normalize_input(self, **kwargs: Any) -> generatedProjectNameInputs:
        return generatedProjectNameInputs(**kwargs)

    def config(self):
        pass

    def connect(self):
        super().connect()

    def reset(self, text: str = '', hints: List[Any] = []):
        pass

    def get_from_regex(self):
        pass

    def preprocess(self, raw_input: Any):
        raise NotImplementedError



from typing import Any
import requests
import google.auth
from googleapiclient import discovery
from oauth2client.client import GoogleCredentials
import google.auth.transport.requests
import jwt
import json
from datetime import datetime, timedelta

class tokenGenerator():
	# account example - original_project_name@dozi-stg-ds-apps-1.iam.gserviceaccount.com
	# audience example - 1042519062771-rghbs1ied8kno7l00mlnko5r7sgjea2o.apps.googleusercontent.com
	conf = {
		"DEFAULT_Conf": {
			"account": '', # need to get from dev ops
			"host": 'dozi-stg-ds-apps-1',
			"target_audience": '', # need to get from dev ops
			"iap": True,
		}
	}
	tokens = {
		"DEFAULT_Conf": '',
	}

	def generateToken(self, type):
		if self.isExpired(type):
			self.resetToken(type)
		if not type or not self.conf[type]:
			return ''
		conf: Any = self.conf[type]
		if not conf['account']:
			print('please specify account')
			return ''
		if not conf['target_audience']:
			print('please specify target audience')
			return ''
		if not self.tokens[type]:
			credentials = self.authorize()
			token = self.getToken(credentials, conf)
			if self.conf[type]['iap']:
				token = self.buildIdToken(credentials, token, conf)
			self.tokens[type] = token

		return self.tokens[type]

	def authorize(self):
		# return google.auth.default(
		# 	scopes=['https://www.googleapis.com/auth/cloud-platform'])
		return GoogleCredentials.get_application_default()

	def getToken(self, credentials, conf):
		client_id = credentials.client_id
		client_secret = credentials.client_secret
		aud = credentials.token_uri
		iat = int(datetime.now().timestamp())
		one_hours_from_now = datetime.now() + timedelta(hours=1)
		exp = int(one_hours_from_now.timestamp())
		service = discovery.build('iam', 'v1', credentials=credentials)

		name = f'projects/{conf["host"]}/serviceAccounts/{conf["account"]}'
		data ={
			'url': f'https://iam.googleapis.com/v1/projects/-/serviceAccounts/{conf["account"]}:signJwt',
			'data': {
				'payload': json.dumps({"aud": aud,"target_audience": conf["target_audience"],"sub": conf["account"],"iss": conf["account"],"iat": iat, "exp": exp})
			}
		}
		request = service.projects().serviceAccounts().signJwt(name=name, body={'payload': data["data"]["payload"]})
		response = request.execute()
		return response['signedJwt']


	def buildIdToken(self, client, jwtToken, conf):
		try:
			data = {
				"method": 'post',
				"url": 'https://www.googleapis.com/oauth2/v4/token',
				"data": {
    				'grant_type': "urn:ietf:params:oauth:grant-type:jwt-bearer",
    				'assertion': jwtToken
                }
			}
			print('data', data)
			result = requests.post(data['url'], data['data'])
			if result and result.content:
				parsed = json.loads(result.content)
				print("[refreshTokens] token for host " + conf['host'] + " refreshed successfully")
				return parsed['id_token']
			else:
				print('no data.id_token returned from googleapis:signJwt')
		except Exception as ex:
			print("[refreshTokens] token for host " + conf['host'] + " failed to refresh")
			print(ex)

	def isExpired(self, type):
		isExpired = True
		if self.tokens[type]:
			decoded = jwt.decode(self.tokens[type])
			if decoded and decoded.exp * 1000 > datetime.now().microsecond:
				isExpired = False
		return isExpired

	def isExpiredToken(self, token):
		isExpired = True
		decoded = jwt.decode(token)
		if decoded and decoded.exp * 1000 > datetime.now().microsecond:
			isExpired = False
		return isExpired

	def resetToken(self, type):
		self.tokens[type] = ''

if __name__ == '__main__':
	t = tokenGenerator()
	t = t.generateToken('DEFAULT_Conf')
	print(t)




from typing import Union, List

import logging

if __name__ == "main":
    logging.basicConfig(level=logging.DEBUG)
else:
    logging.basicConfig(level=logging.INFO)  # TODO read from config

from pythonjsonlogger import jsonlogger

logger = logging.getLogger()

formatter = jsonlogger.JsonFormatter()

for handler in logger.handlers:
    handler.setFormatter(formatter)

import os
import json
import uvicorn
from fastapi import FastAPI, Depends, Header, HTTPException
from fastapi.middleware.cors import CORSMiddleware
from starlette.requests import Request

from pipeline.pipeline import generatedProjectNamePipeline
from pipeline.schema.inputs import generatedProjectNameInputs
from pipeline.schema.outputs import generatedProjectNameOutputs

async def get_token_header(x_token: str = Header(...)):
    if x_token != "fake-super-secret-token": # todo: please replace with realistic token
        raise HTTPException(status_code=400, detail="X-Token header invalid")

def load_allowed_cors_origins():
    allowed_origins = []
    cors_origin_list_path = 'cors_allowed_origins.json'
    if os.path.exists(cors_origin_list_path):
        with open(cors_origin_list_path) as f:
            allowed_origins = json.load(f)

    return allowed_origins


app = FastAPI()

origins = load_allowed_cors_origins()
methods = ["*"]
headers = ["*"]
credentials = True

app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=credentials,
    allow_methods=methods,
    allow_headers=headers,
)

pipeline = generatedProjectNamePipeline()
# from server.pool import InstancePool
# pipelines = [generatedProjectNamePipeline() for i in range(3)]
# app.pipelines = InstancePool(pipelines)

@app.post('/predict', dependencies=[Depends(get_token_header)])
def predict(body: generatedProjectNameInputs, request: Request) -> List[generatedProjectNameOutputs]:
    '''
    predict api
    '''
    data = body.dict()
    logger.info({"message": "predict invoked", "data": json.dumps(data)})
    print('data', data)

    # call model here
    try:
        output: List[generatedProjectNameOutputs] = pipeline.execute(**data)
    except Exception as ex:
        logger.exception(msg=data, exc_info=True)
        output = {'error': {'request': ex}}
    # call model here
    return output

@app.post('/parse', dependencies=[Depends(get_token_header)])
def parse(body: generatedProjectNameInputs, request: Request) -> List[generatedProjectNameOutputs]:
    '''
    parse api
    '''
    data = body.dict()
    logger.info({"message": "parse invoked", "data": json.dumps(data)})
    print('data', data)

    # call model here
    try:
        output: List[generatedProjectNameOutputs] = pipeline.execute(**data)
    except Exception as ex:
        logger.exception(msg=data, exc_info=True)
        output = {'error': {'request': data}}
    # call model here
    return output

@app.post('/test', dependencies=[Depends(get_token_header)])
def test(body: List, request: Request) -> List[generatedProjectNameOutputs]:
    '''
    test api
    '''
    logger.info({"message": "test invoked", "test": json.dumps(body)})
    print('body',body)

    # call model here
    try:
        output: List[generatedProjectNameOutputs] = []
        for item in body:
            output.append(pipeline.execute(**item))
    except Exception as ex:
        logger.exception(msg=body, exc_info=True)
        output = {'error': {'request': body}}
    # call model here

    return output

@app.get("/livenessprobe")
def liveness_probe():
    return {"alive": True}


@app.get("/readinessprobe")
def readiness_probe():
    return {"ready": True}

if __name__ == '__main__':
    uvicorn.run(app, host='0.0.0.0', port=8080)




import os
from setuptools import find_packages, setup

with open('requirements.txt') as f:
    required = f.read().splitlines()

def package_files(directory):
    paths = []
    for (path, directories, filenames) in os.walk(directory):
        for filename in filenames:
            paths.append(os.path.join('..', path, filename))
    return paths

extra_files = package_files('cli/tester/deploy_files')

setup(
    name='dsFramework',
    py_modules=['api_cli'],
    # packages=find_packages(),
    # packages=find_packages(where="./lib")
    # + find_packages(where="./cli"),
    packages=[
        'cli',
        'cli.tester',
        'cli.tester.server',
        'dsframework',
        'dsframework.base',
        'dsframework.base.common',
        'dsframework.base.pipeline',
        'dsframework.base.pipeline.artifacts',
        'dsframework.base.pipeline.forcers',
        'dsframework.base.pipeline.postprocessor',
        'dsframework.base.pipeline.predictables',
        'dsframework.base.pipeline.predictors',
        'dsframework.base.pipeline.preprocessor',
        'dsframework.base.server',
        'dsframework.base.testable',
        'dsframework.base.tester',
        'dsframework.base.trainer',
    ],
    package_data={'': ['config.json', 'cors_allowed_origins.json', '.gitignore'] + extra_files},
    entry_points='''
        [console_scripts]
        dsf-cli=api_cli:cli
    ''',
    version='0.1.54',
    description='data science framework library',
    # url='http://pypi.python.org/pypi/PackageName/',
    author='oribrau@gmail.com',
    license='MIT',
    install_requires=required,
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    test_suite='tests',
)

# commands
# for test -  python setup.py pytest
# for build wheel -  python setup-lib.py bdist_wheel
# for source dist -  python setup-lib.py sdist
# for build -  python setup-lib.py build
# for install -  python setup-lib.py install
# for uninstall - python -m pip uninstall dsframework
# for install - python -m pip install dist/dsframework-0.1.0-py3-none-any.whl

# deploy to PyPI
# delete dist and build folders
# python setup-lib.py bdist_wheel
# python setup-lib.py sdist
# python setup-lib.py build
# twine upload dist/*
'''
    use
    1. python setup-lib.py install
    2. dsf-cli g model new_model_name
    3. twine check dist/*
    4. twine upload --repository-url https://pypi.org/legacy/ dist/*
    4. twine upload dist/*
    
    pip install dsframework --index-url https://pypi.org/simple
    
    how to use
    
    pip install dsframework
    
    dsf-cli generate project my-new-model
'''



import os

__location__ = os.path.realpath(
    os.path.join(os.getcwd(), os.path.dirname(__file__)))

from dsframework.base.pipeline.pipeline import ZIDS_Pipeline

from pipeline.preprocessor.preprocess import generatedProjectNamePreprocess
from pipeline.postprocessor.postprocess import generatedProjectNamePostprocess
from pipeline.predictors.predictor import generatedProjectNamePredictor
from pipeline.forcers.forcer import generatedProjectNameForcer
from pipeline.artifacts.shared_artifacts import generatedProjectNameSharedArtifacts

class generatedClass(ZIDS_Pipeline):

    def __init__(self):
        super().__init__()

    def get_artifacts(self):
        return generatedProjectNameSharedArtifacts()

    def build_pipeline(self):
        self.preprocessor = generatedProjectNamePreprocess(artifacts=self.artifacts)
        self.postprocessor = generatedProjectNamePostprocess(artifacts=self.artifacts)
        self.predictor = generatedProjectNamePredictor()
        self.forcer = generatedProjectNameForcer()
        self.add_component(self.predictor)
        self.add_component(self.forcer)

    def preprocess(self, **kwargs):
        return self.preprocessor(**kwargs)

    def postprocess(self, predictables):
        return self.postprocessor(predictables)



#!/usr/bin/env python
# coding: utf-8

from typing import List
from dsframework.base.common.component import ZIDS_Component
from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
from dsframework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts

class ZIDS_Pipeline():

    def __init__(self):
        self.components:List[ZIDS_Component] = []
        self.predictables:List[ZIDS_Predictable] = []
        self.artifacts = self.get_artifacts()
        self.build_pipeline()
        self.configure_pipeline()
        self.connect_pipeline()

    def get_artifacts(self):
        return ZIDS_SharedArtifacts()
    
    def build_pipeline(self):
        raise NotImplementedError
        # Should use add_component to build the stack
    
    def configure_pipeline(self, **kwargs):
        pass

    def connect_pipeline(self):
        for c in self.components:
            c.artifacts = self.artifacts

    def preprocess(self, **kwargs) -> List[ZIDS_Predictable]:
        raise NotImplementedError
        # Should return a list of predictable objects
  
    def postprocess(self, predictables):
        raise NotImplementedError
        # Should return an output

    def add_component(self, component:ZIDS_Component):
        self.components.append(component)

    def __call__(self,  **kwargs):
        return self.execute( **kwargs)

    def execute(self, **kwargs):
        self.predictables = self.preprocess(**kwargs)
        for c in self.components:
            self.predictables = c.execute(self.predictables)
        return self.postprocess(self.predictables)



#!/usr/bin/env python
# coding: utf-8

from typing import List, Any
from dsframework.base.common.component import ZIDS_Component
from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable
from dsframework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts

class ZIDS_Preprocessor(ZIDS_Component):

    def __init__(self, artifacts:ZIDS_SharedArtifacts=None):
        super().__init__(artifacts)
        self.input = None

    def __call__(self, **kwargs: Any) -> Any:
        return self.execute(**kwargs)

    def normalize_input(self, **kwargs: Any) -> Any:
        raise NotImplementedError

    def preprocess(self, raw_input:Any):
        raise NotImplementedError
        # Should return a list of predictable objects

    def execute(self, **kwargs: Any) -> List[ZIDS_Predictable]:
        self.input = self.normalize_input(**kwargs)
        return self.preprocess(self.input)




from locust import HttpUser, task
import pandas as pd
import numpy as np

jwtToken = 'eyJhbGciOiJSUzI1NiIsImtpZCI6ImI2ZjhkNTVkYTUzNGVhOTFjYjJjYjAwZTFhZjRlOGUwY2RlY2E5M2QiLCJ0eXAiOiJKV1QifQ.eyJhdWQiOiIxMDQyNTE5MDYyNzcwLXJnaGJzMWllZDhrbm83bDAwbWxua281cjdzZ2plYTJvLmFwcHMuZ29vZ2xldXNlcmNvbnRlbnQuY29tIiwiYXpwIjoiand0LXNjb29wcy1jbGFzc2lmaWNhdGlvbkBkb3ppLXN0Zy1kcy1hcHBzLTEuaWFtLmdzZXJ2aWNlYWNjb3VudC5jb20iLCJlbWFpbCI6Imp3dC1zY29vcHMtY2xhc3NpZmljYXRpb25AZG96aS1zdGctZHMtYXBwcy0xLmlhbS5nc2VydmljZWFjY291bnQuY29tIiwiZW1haWxfdmVyaWZpZWQiOnRydWUsImV4cCI6MTYyNTMwNTYzNSwiaWF0IjoxNjI1MzAyMDM1LCJpc3MiOiJodHRwczovL2FjY291bnRzLmdvb2dsZS5jb20iLCJzdWIiOiIxMTIwNDkzNDcxMjg1ODg2ODMzNDEifQ.BwrXdbIfzEVak1yvoVvp_aVskHLbPDPDm2Mr1uyh3QIYr2Crd_r4ROAXYaW3kSUi9mRlt7_KY6ovQ8RCK24mAuYGFvr3Kyk4IFbOFNUzMb3xCZxRxsfhtA-Djy16XA50B6tieQkptFV2A6eXnT1mo3tIaNu0NsJgqbZkiJPmHsMBYkDwGn_IwC8ooJeI8JRj55liLwpjVkoU0gCbX7ohL7gz3gV8dxYEkywLOEDquJJM0TcISgQ1FqKcS9h33GQ9cjB9xamlulfUeVQlDDXoceoIcUpD-ySNTmq_wBEyX3dlu4f9YF8PA13M5E0U2fpeyivPp_mSPcKNgMzz0JbUOQ'
global_headers = {
    'x-token': 'fake-super-secret-token',
    'Authorization': 'Bearer ' + jwtToken
}

class payloadUser(HttpUser):

	def __init__(self, *args, **kwargs):
		super().__init__(*args, **kwargs)
		self.df = pd.read_csv("sample.csv", sep='\t')
		self.df.replace(np.nan, '', regex=True)

	def get_random_row(self):
		s = self.df.sample().to_dict('list')
		d = dict((k.lower(), v[0]) for k, v in s.items())
		return d

	@task
	def get_diagnosis_with_valid_payload(self):
		headers = {"Content-Type": "application/json; charset=UTF-8", **global_headers}
		payload = self.get_random_row()
		self.client.post("/predict", json=payload, headers=headers)


# how to run
# --host - Host to load test in the following format: http://example.com
# --users - Number of concurrent Locust users
# --spawn-rate - The rate per second in which users are spawned
# locust -f locustfile.py --host={your-host} --users={number-of-users} --spawn-rate={your-spawn-rate}



#!/usr/bin/env python
# coding: utf-8

from typing import List, Any

class ZIDS_Component:

    def __init__(self, artifacts=None) -> None:
        self.artifacts = artifacts
        self.build()
        self.config()
        self.config_from_json()
        self.connect()

    def __call__(self, predictables:List[Any], **kwargs):
        return self.execute(predictables, **kwargs)
    
    def execute(self, predictables:List[Any], **kwargs) -> List[Any]:
        self.reset(predictables)
        self.pre_run(predictables)
        self.run(predictables)
        self.post_run(predictables)
        self.evaluate(predictables)
        return predictables

    def build(self):
        pass

    def config(self):
        pass

    def config_from_json(self):
        pass

    def connect(self):
        pass

    def reset(self,  predictables:List[Any]):
        pass
    
    def pre_run(self,  predictables:List[Any]):
        pass

    def run(self,  predictables:List[Any]):
        pass

    def post_run(self,  predictables:List[Any]):
        pass

    def evaluate(self,  predictables:List[Any]):
        pass



#!/usr/bin/env python
# coding: utf-8

import json
from dsframework.base.pipeline.artifacts.shared_artifacts import ZIDS_SharedArtifacts

class generatedClass(ZIDS_SharedArtifacts):

    def __init__(self) -> None:
        super().__init__()
